#
# Makefile Template for Tessy
# Compiler: ARM RVDS
# Debugger: Keil Vision
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# ALIGN_COMM_BUFFER     :=
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_DIALECT      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# SCATTER_FILE          :=
# STARTUP_FILE          :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s $(TESSY_SYS))
MODULE_PATH_DOS := $(shell ts_pathname -s '$(MODULE_PATH)')
ARM_HOME        := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
ARM_CC          := $(shell ts_pathname -s '$(ARM_HOME)/ARMCC')
ARM_LIB         := $(shell ts_pathname -s '$(ARM_CC)/lib')
ARM_CC_INC      := $(shell ts_pathname -s '$(ARM_CC)/include')
ARM_INC         := $(shell ts_pathname -s '$(ARM_HOME)/PACK/ARM/CMSIS/$(CMSIS_VERSION)/CMSIS/Include')
ARM_DEVICE_INC  := $(shell ts_pathname -s '$(ARM_HOME)/PACK/ARM/CMSIS/$(CMSIS_VERSION)/Device/ARM/ARMCM4/Include')
UVSC_HOME       := $(shell ts_pathname -s '$(TARGET_INSTALL_PATH)')

ifeq ($(ALIGN_COMM_BUFFER),)
ALIGN_COMM_BUFFER := 0
endif

#
ifneq ($(CPU),)
CPU_OPT			 := --cpu $(CPU)
else
CPU_OPT			 := --cpu Cortex-M3
endif

TS_NAME         := TS_UVISION
IDE_NAME        := uvision_uvsc
COMPANY_NAME    := keil
PROCESSOR_NAME  := arm_rvds

all    : master slave
master : $(MODULE_PATH)/ts_$(TESTOBJECT)_m.exe
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION)

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(PROCESSOR_NAME).mk

#
# SLAVE
# (You may change these settings to use your own compiler/linker options)
#
S_COMP_OPTIONS := $(CPU_OPT) $(COMPILER_DIALECT) -g -O0 --apcs=interwork -I$(ARM_CC_INC) -I$(ARM_INC) -I$(ARM_DEVICE_INC) \
                  -DTESSY -DTS_SLAVE -DTS_RVDS_ARM -DTS_ARM -DTS_HAVE_INT64 -DTS_HAVE_FLOAT64 \
                  -DTS_ALIGN_BUFFER=$(ALIGN_COMM_BUFFER) -DTS_HAVE___int64
S_LINK_OPTIONS := $(CPU_OPT) --scatter $(SCATTER_FILE) --autoat --libpath $(ARM_LIB)
S_INCLUDES     := -I$(TESSY_SYS_DOS)\include\tessy\comm -I$(MODULE_PATH_DOS)

S_CC           := $(ARM_CC)\bin\armcc.exe
S_ASM          := $(ARM_CC)\bin\armasm.exe
S_LINK         := $(ARM_CC)\bin\armlink.exe
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

#
# Startup and System cod
#
ifneq ($(STARTUP_FILE),)
STARTUP_OBJECT = $(MODULE_PATH_DOS)\Startup$(OBJFILE_EXTENSION)
endif
ifneq ($(SYSTEM_FILE),)
SYSTEM_OBJECT = $(MODULE_PATH_DOS)\System$(OBJFILE_EXTENSION)
endif


#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -o $@ -c "$<"


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################


#
# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	@echo ***** Compiling Usercode *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	@echo ***** Compiling Stubs *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<

#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)

#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -o $@ -c $<

#
# Handle Board Files
#
ifeq ("true","$(USE_BOARD_FILES)")
ifeq ("","$(INITOBJDIR)")
$(error Attribute 'Use Board Files' is set to true but 'InitObjDir' is empty.)
endif
INITOBJDIR := $(shell ts_pathname -s '$(INITOBJDIR)')
ifeq ("","$(INITSRCDIR)")
$(info Attribute 'InitSrcDir' is empty. Using objects for linking only.)
START_OBJS := $(wildcard $(INITOBJDIR)/*$(OBJFILE_EXTENSION))
else
INITSRCDIR := $(shell ts_pathname -s '$(INITSRCDIR)')
START_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
              $(patsubst $(INITSRCDIR)/%.s,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.s))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -I$(INITSRCDIR) "$<" -o"$@"

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.s
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) "$<" -o"$@"
endif
ifeq ("","$(START_OBJS)")
$(warning Attribute 'Use Board Files' is set to true but no objects were found.)
endif
endif

#
# Startup object
#
$(STARTUP_OBJECT) : $(STARTUP_FILE)
	$(S_ASM) $(CPU_OPT) -g --apcs=interwork --pd "__MICROLIB SETA 1" -o "$@" "$<"

#
# System object
#
ifneq ($(SYSTEM_OBJECT),)
$(SYSTEM_OBJECT) : $(SYSTEM_FILE)
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -o $@ -c $<
endif


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(EXEFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
									$(S_SRC_OBJECTS) \
									$(START_OBJS) \
									$(S_UC_OBJECT) \
									$(S_STUB_OBJECT) \
									$(S_OBJECTS) \
									$(STARTUP_OBJECT) \
									$(SYSTEM_OBJECT)

	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) $(USER_LINK_OPTIONS) --output $@ $(STARTUP_OBJECT) $(SYSTEM_OBJECT) $(START_OBJS) \
		$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) $(S_SRC_OBJECTS) \
		$(S_UC_OBJECT) $(S_STUB_OBJECT) $(S_OBJECTS)
	@-ts_rm "$(MODULE_PATH)"/*$(OBJFILE_EXTENSION)

#####################################################################
#END_TARGETS
#####################################################################












